@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -30,7 +30,7 @@ use Data::Dumper;
 
 #  Version information
 #
-$VERSION='2.074_566';
+$VERSION='2.034';
 
 
 #  Shortcut error handler.
@@ -57,13 +57,12 @@ sub import {
 
     #  Will only work if called from within a __PERL__ block in WebDyne
     #
-    my $class=shift();
     my $self_cr=UNIVERSAL::can(scalar(caller), 'self') || return;
     my $self=$self_cr->()                              || return;
 
     $self->set_handler('WebDyne::Chain');
     my $meta_hr=$self->meta();
-    push @{$meta_hr->{'webdynechain'}}, $class;
+    push @{$meta_hr->{'webdynechain'}}, __PACKAGE__;
 
 
 }
